@@ -32,11 +32,10 @@ private Q_SLOTS:
     void onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies policies);
 
 private:
-    void setBrightnessHelper(const QMap<QString, int> &screenBrightness, int keyboardBrightness);
+    void setKeyboardBrightnessHelper(int keyboardBrightness);
 
     std::chrono::milliseconds m_dimOnIdleTime{0};
 
-    QMap<QString, int> m_oldScreenBrightness;
     int m_oldKeyboardBrightness = 0;
 
     PowerDevil::PolicyAgent::RequiredPolicies m_inhibitScreen = PowerDevil::PolicyAgent::None;
