@@ -47,10 +47,8 @@ public:
     int knownSafeMinBrightness() const override;
     int maxBrightness() const override;
     int brightness() const override;
-    void setBrightness(int value) override;
+    void setBrightness(int value, bool allowAnimations) override;
     bool supportsBrightness() const;
-    void resumeWorker();
-    void pauseWorker();
     std::optional<QByteArray> edidData() const override;
 
 Q_SIGNALS:
