@@ -104,6 +104,18 @@ QStringList ScreenBrightnessController::displayIds() const
     return m_sortedDisplayIds;
 }
 
+QStringList ScreenBrightnessController::displayIds(const DisplayFilter &filter) const
+{
+    auto appendIfIncluded = [this, &filter](QStringList &&filtered, const QString &displayId) {
+        const DisplayMatch &match = m_displaysById.find(displayId)->second.match;
+        if (filter.includes(match)) {
+            filtered.append(displayId);
+        }
+        return filtered;
+    };
+    return std::accumulate(m_sortedDisplayIds.constBegin(), m_sortedDisplayIds.constEnd(), QStringList{}, appendIfIncluded);
+}
+
 void ScreenBrightnessController::onDisplayDestroyed(QObject *obj)
 {
     for (auto &[id, info] : m_displaysById) {
@@ -515,16 +527,14 @@ double ScreenBrightnessController::dimmingRatioForDisplay(const QString &display
 KScreen::OutputPtr ScreenBrightnessController::tryMatchKScreenOutput(const QString &displayId) const
 {
     if (const auto it = m_displaysById.find(displayId); it != m_displaysById.end() && !it->second.zombie && m_kscreenConfig) {
-        const DisplayBrightness *display = it->second.display;
+        const DisplayMatch &displayMatch = it->second.match;
         for (const KScreen::OutputPtr &output : m_kscreenConfig->outputs()) {
-            if (display->id() == output->name()) { // for KWinDisplayDetector, primarily
-                return output;
-            }
-            if (output->type() == KScreen::Output::Panel && display->isInternal()) {
-                return output;
-            }
-            const std::optional<QByteArray> displayEdid = display->edidData();
-            if (displayEdid && output->edid() && output->edid()->rawData().startsWith(*displayEdid)) {
+            bool matched = DisplayFilter()
+                               .includeByDefault(false)
+                               .isInternalEquals(output->type() == KScreen::Output::Panel)
+                               .includeEdids(output->edid() ? QList<QByteArray>{output->edid()->rawData()} : QList<QByteArray>{})
+                               .includes(displayMatch);
+            if (matched) {
                 return output;
             }
         }
