@@ -47,12 +47,7 @@ bool Action::isSupported()
     return true;
 }
 
-BackendInterface *Action::backend() const
-{
-    return m_core->backend();
-}
-
-Core *Action::core()
+Core *Action::core() const
 {
     return m_core;
 }
