@@ -1,6 +1,7 @@
 /*
  *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
  *   SPDX-FileCopyrightText: 2012 Lukáš Tinkl <ltinkl@redhat.com>
+ *   SPDX-FileCopyrightText: 2024 Natalie Clarius <natalie.clarius@kde.org>
  *
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -16,6 +17,10 @@
 #include <QDBusContext>
 #include <QDBusUnixFileDescriptor>
 
+#include <KSharedConfig>
+#include <qobjectdefs.h>
+
+#include "PowerDevilGlobalSettings.h"
 #include "powerdevilcore_export.h"
 
 class QDBusServiceWatcher;
@@ -23,15 +28,15 @@ class QDBusInterface;
 
 class OrgFreedesktopScreenSaverInterface;
 
-#define SYSTEMD_LOGIN1_SERVICE "org.freedesktop.login1"
-#define SYSTEMD_LOGIN1_PATH "/org/freedesktop/login1"
-#define SYSTEMD_LOGIN1_MANAGER_IFACE "org.freedesktop.login1.Manager"
-#define SYSTEMD_LOGIN1_SESSION_IFACE "org.freedesktop.login1.Session"
-#define SYSTEMD_LOGIN1_SEAT_IFACE "org.freedesktop.login1.Seat"
+inline constexpr QLatin1StringView SYSTEMD_LOGIN1_SERVICE("org.freedesktop.login1");
+inline constexpr QLatin1StringView SYSTEMD_LOGIN1_PATH("/org/freedesktop/login1");
+inline constexpr QLatin1StringView SYSTEMD_LOGIN1_MANAGER_IFACE("org.freedesktop.login1.Manager");
+inline constexpr QLatin1StringView SYSTEMD_LOGIN1_SESSION_IFACE("org.freedesktop.login1.Session");
+inline constexpr QLatin1StringView SYSTEMD_LOGIN1_SEAT_IFACE("org.freedesktop.login1.Seat");
 
-#define CONSOLEKIT_SERVICE "org.freedesktop.ConsoleKit"
-#define CONSOLEKIT_MANAGER_PATH "/org/freedesktop/ConsoleKit/Manager"
-#define CONSOLEKIT_MANAGER_IFACE "org.freedesktop.ConsoleKit.Manager"
+inline constexpr QLatin1StringView CONSOLEKIT_SERVICE("org.freedesktop.ConsoleKit");
+inline constexpr QLatin1StringView CONSOLEKIT_MANAGER_PATH("/org/freedesktop/ConsoleKit/Manager");
+inline constexpr QLatin1StringView CONSOLEKIT_MANAGER_IFACE("org.freedesktop.ConsoleKit.Manager");
 
 using InhibitionInfo = QPair<QString, QString>;
 
@@ -51,6 +56,7 @@ struct LogindInhibition {
 
 namespace PowerDevil
 {
+class GlobalSettings;
 class POWERDEVILCORE_EXPORT PolicyAgent : public QObject, protected QDBusContext
 {
     Q_OBJECT
@@ -85,15 +91,22 @@ public:
 public Q_SLOTS:
     // Exported slots
     uint AddInhibition(uint types, const QString &appName, const QString &reason);
-    void ReleaseInhibition(uint cookie);
+    void ReleaseInhibition(uint cookie, bool retainCookie = false);
     QList<InhibitionInfo> ListInhibitions() const;
     bool HasInhibition(uint types);
 
     void releaseAllInhibitions();
 
+    void BlockInhibition(const QString &appName, const QString &reason, bool permanently);
+    void UnblockInhibition(const QString &appName, const QString &reason, bool permanently);
+    QList<InhibitionInfo> ListPermanentlyBlockedInhibitions() const;
+    QList<InhibitionInfo> ListTemporarilyBlockedInhibitions() const;
+
 Q_SIGNALS:
     // Exported signals
     void InhibitionsChanged(const QList<InhibitionInfo> &added, const QStringList &removed);
+    void PermanentlyBlockedInhibitionsChanged(const QList<InhibitionInfo> &added, const QList<InhibitionInfo> &removed);
+    void TemporarilyBlockedInhibitionsChanged(const QList<InhibitionInfo> &added, const QList<InhibitionInfo> &removed);
 
     void unavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies newpolicies);
     void sessionActiveChanged(bool active);
@@ -111,7 +124,7 @@ private Q_SLOTS:
 private:
     explicit PolicyAgent(QObject *parent = nullptr);
 
-    void init();
+    void init(GlobalSettings *globalSettings);
 
     void addInhibitionTypeHelper(uint cookie, RequiredPolicies types);
 
@@ -152,6 +165,9 @@ private:
     QHash<uint, LogindInhibition> m_logindInhibitions;
 
     QList<int> m_pendingInhibitions;
+    QSet<uint> m_activeInhibitions;
+    QSet<uint> m_blockedInhibitions;
+    QSet<uint> m_pendingBlockedInhibitions;
 
     uint m_lastCookie;
 
@@ -161,8 +177,17 @@ private:
 
     bool m_wasLastActiveSession;
 
+    GlobalSettings *m_config = nullptr;
+    QSet<InhibitionInfo> m_configuredToBlockInhibitions;
+
+    QHash<uint, QMetaObject::Connection> m_blockInhibitionConnections;
+    QHash<uint, QMetaObject::Connection> m_unblockInhibitionConnections;
+
     friend class Core;
     friend class FdoConnector;
-};
 
+Q_SIGNALS:
+    void blockInhibitionRequested(InhibitionInfo info, bool permanently);
+    void unblockInhibitionRequested(InhibitionInfo info, bool permanently);
+};
 }
